@@ -1,7 +1,8 @@
 package Git::Database;
-$Git::Database::VERSION = '0.001';
+$Git::Database::VERSION = '0.002';
 use Module::Runtime qw( use_module );
 
+use Moo::Object ();
 use namespace::clean;
 
 sub new {
@@ -9,9 +10,14 @@ sub new {
 
     # store: an object that gives actual access to a git repo
     if ( my $store = delete $args->{store} ) {
-
-        return use_module( "Git::Database::Backend::" . ref $store )
-          ->new( store => $store );
+        if ( !ref $store || -d $store ) {
+            require Git::Database::Backend::Git::Sub;
+            return Git::Database::Backend::Git::Sub->new( store => $store );
+        }
+        else {
+            return use_module( "Git::Database::Backend::" . ref $store )
+              ->new( store => $store );
+        }
     }
 
     # some really basic default
@@ -30,7 +36,7 @@ Git::Database - Provide access to the Git object database
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
