@@ -1,5 +1,6 @@
 package Git::Database::Backend::Git::Repository;
-$Git::Database::Backend::Git::Repository::VERSION = '0.001';
+$Git::Database::Backend::Git::Repository::VERSION = '0.002';
+use IO::Select;
 use Sub::Quote;
 
 use Moo;
@@ -57,6 +58,12 @@ sub get_object_meta {
     local $/ = "\012";
     chomp( my $reply = $checker->stdout->getline );
 
+    # git error messages
+    my $bang;
+    my $select = IO::Select->new( my $err = $checker->stderr );
+    $bang .= $err->getline while $select->can_read(0);
+    warn $bang if $bang;
+
     # protect against weird cases like if $digest contains a space
     my @parts = split / /, $reply;
     return ( $digest, 'missing', undef ) if $parts[-1] eq 'missing';
@@ -80,6 +87,12 @@ sub get_object_attributes {
     # protect against weird cases like if $sha1 contains a space
     my ( $sha1, $kind, $size ) = my @parts = split / /, $reply;
 
+    # git error messages
+    my $bang;
+    my $select = IO::Select->new( my $err = $factory->stderr );
+    $bang .= $err->getline while $select->can_read(0);
+    warn $bang if $bang;
+
     # object does not exist in the git object database
     return if $parts[-1] eq 'missing';
 
@@ -111,11 +124,25 @@ sub get_object_attributes {
 
 sub all_digests {
     my ( $self, $kind ) = @_;
+    my $store = $self->store;
     my $re = $kind ? qr/ \Q$kind\E / : qr/ /;
 
-    return map +( split / / )[0],
-      grep /$re/,
-      $self->store->run(qw( cat-file --batch-check --batch-all-objects ));
+    # the --batch-all-objects option appeared in v2.6.0-rc0
+    if ( $store->version_ge('2.6.0.rc0') ) {
+        return map +( split / / )[0],
+          grep /$re/,
+          $store->run(qw( cat-file --batch-check --batch-all-objects ));
+    }
+    else {    # this won't return unreachable objects
+        my $batch = $store->command(qw( cat-file --batch-check ));
+        my ( $stdin, $stdout ) = ( $batch->stdin, $batch->stdout );
+        my @digests =
+          map +( split / / )[0], grep /$re/,
+          map { print {$stdin} ( split / / )[0], "\n"; $stdout->getline }
+          sort $store->run(qw( rev-list --all --objects ));
+        $batch->close;
+        return @digests;
+    }
 }
 
 # Git::Database::Role::ObjectWriter
@@ -178,18 +205,14 @@ Git::Database::Backend::Git::Repository - A Git::Database backend based on Git::
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
     # get a store
     my $r  = Git::Repository->new();
 
-    # provide the backend
-    my $b  = Git::Database::Backend::Git::Repository->new( store => $r );
-    my $db = Git::Database->new( backend => $b );
-
-    # let Git::Database figure it out by itself
+    # let Git::Database produce the backend
     my $db = Git::Database->new( store => $r );
 
 =head1 DESCRIPTION
